<?php
/**
 * Bloxic functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Bloxic
 */

 /**
 * Define Core File
 */
  define( 'BLOXIC_THEME_DRI', get_template_directory() );
  define( 'BLOXIC_THEME_URI', get_template_directory_uri() );
  define( 'BLOXIC_CSS_PATH', BLOXIC_THEME_URI . '/assets/css' );
  define( 'BLOXIC_JS_PATH', BLOXIC_THEME_URI . '/assets/js' );
  define( 'BLOXIC_ICON_PATH', BLOXIC_THEME_URI . '/assets/fonts/fontawesome/css' );
  define( 'BLOXIC_IMG_PATH', BLOXIC_THEME_URI . '/assets/images' );


/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function bloxic_setup() {
	/*
		* Make theme available for translation.
		* Translations can be filed in the /languages/ directory.
		* If you're building a theme based on Bloxic, use a find and replace
		* to change 'bloxic' to the name of your theme in all the template files.
		*/
	load_theme_textdomain( 'bloxic', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );
	remove_theme_support( 'widgets-block-editor' );

	//bloxic image size
	add_image_size('bloxic-img-size-1', 640, 390, true );
	add_image_size('bloxic-img-size-2', 420, 267, true );
	add_image_size('bloxic-img-size-3', 977, 529, true );

	//woocommerce Support
	add_theme_support( 'woocommerce' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );

	/*
		* Let WordPress manage the document title.
		* By adding theme support, we declare that this theme does not use a
		* hard-coded <title> tag in the document head, and expect WordPress to
		* provide it for us.
		*/
	add_theme_support( 'title-tag' );

	/*
		* Enable support for Post Thumbnails on posts and pages.
		*
		* @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		*/
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus(
		array(
			'main_menu' => esc_html__( 'Main Menu', 'bloxic' ),
			'category_menu' => esc_html__( 'Category Menu', 'bloxic' ),
		)
	);

	/*
		* Switch default core markup for search form, comment form, and comments
		* to output valid HTML5.
		*/
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'style',
			'script',
		)
	);

	// Set up the WordPress core custom background feature.
	add_theme_support(
		'custom-background',
		apply_filters(
			'bloxic_custom_background_args',
			array(
				'default-color' => 'ffffff',
				'default-image' => '',
			)
		)
	);

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	add_theme_support(
		'custom-logo',
		array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		)
	);
}
add_action( 'after_setup_theme', 'bloxic_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function bloxic_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'bloxic_content_width', 640 );
}
add_action( 'after_setup_theme', 'bloxic_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function bloxic_widgets_init() {
	register_sidebar(		
		array(
			'name'          => esc_html__( 'Sidebar', 'bloxic' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'bloxic' ),
			'before_widget' => '<div id="%1$s" class="widget sidebar-widget-two %2$s"><div class="widget-content">',
			'after_widget'  => '</div></div>',
			'before_title'  => '<div class="sidebar-title-two"><h5 class="widget-title">',
			'after_title'   => '</h5></div>',
		)
	);
	// Footer Widget
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer One', 'bloxic' ),
			'id'            => 'footer-1',
			'description'   => esc_html__( 'Add Widgets here.', 'bloxic' ),
			'before_widget' => '<section id="%1$s" class="footer-widget links-widget %2$s"><div class="page-list">',
			'after_widget'  => '</div></section>',
			'before_title'  => '<h5>',
			'after_title'   => '</h5>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer Two', 'bloxic' ),
			'id'            => 'footer-2',
			'description'   => esc_html__( 'Add Widgets here.', 'bloxic' ),
			'before_widget' => '<section id="%1$s" class="footer-widget links-widget %2$s"><div class="page-list">',
			'after_widget'  => '</div></section>',
			'before_title'  => '<h5>',
			'after_title'   => '</h5>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer Three', 'bloxic' ),
			'id'            => 'footer-3',
			'description'   => esc_html__( 'Add Widgets here.', 'bloxic' ),
			'before_widget' => '<section id="%1$s" class="footer-widget links-widget %2$s"><div class="page-list">',
			'after_widget'  => '</div></section>',
			'before_title'  => '<h5>',
			'after_title'   => '</h5>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Shop Sidebar', 'bloxic' ),
			'id'            => 'shop-sidebar-1',
			'description'   => esc_html__( 'Add Shop Sidebar here.', 'bloxic' ),
			'before_widget' => '<div id="%1$s" class="sidebar-widget shop-widget links-widget %2$s"><div class="widget-content">',
			'after_widget'  => '</div></div>',
			'before_title'  => '<div class="sidebar-title"><h6>',
			'after_title'   => '</h6></div>',
		)
	);
}
add_action( 'widgets_init', 'bloxic_widgets_init' );

/**
 *Google Font Load 
 */
if ( ! function_exists( 'bloxic_fonts_url' ) ) :
/**
 * Register Google fonts for Blessing.
 */
function bloxic_fonts_url() {
	$fonts_url     = '';
	$font_families = array();
	$subsets       = 'latin';


	if ( 'off' !== _x( 'on', 'Outfit: on or off', 'bloxic' ) ) {
		$font_families[] = 'Outfit:100,200,300,400,500,600,700,800,900,';
	}

	if ( 'off' !== _x( 'on', 'Jost: on or off', 'bloxic' ) ) {
		$font_families[] = 'Jost:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	}

	if ( 'off' !== _x( 'on', 'Josefin Sans: on or off', 'bloxic' ) ) {
		$font_families[] = 'Josefin Sans:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i';
	}
	

	if ( $font_families ) {
		$fonts_url = add_query_arg( array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( $subsets ),
		), 'https://fonts.googleapis.com/css' );
	}

	return esc_url_raw( $fonts_url );
}
endif;

/**
 * Enqueue scripts and styles.
 */
function bloxic_scripts() {
	//Bloxic Google Font Load
	wp_enqueue_style( 'bloxic-google-fonts', bloxic_fonts_url(), array(), null );

	//Bloxic Stylesheet Load
	wp_enqueue_style( 'bootstrap', BLOXIC_CSS_PATH . '/bootstrap.css' );
	wp_enqueue_style( 'jquery-bootstrap-touchspin', BLOXIC_CSS_PATH . '/jquery.bootstrap-touchspin.css' );
	wp_enqueue_style( 'odometer-theme-default', BLOXIC_CSS_PATH . '/odometer-theme-default.css' );
	wp_enqueue_style( 'font-awesomes', BLOXIC_CSS_PATH . '/fontawesome.css' );
	wp_enqueue_style( 'flaticon', BLOXIC_CSS_PATH . '/flaticon.css' );
	wp_enqueue_style( 'animate', BLOXIC_CSS_PATH . '/animate.css' );
	wp_enqueue_style( 'owl', BLOXIC_CSS_PATH . '/owl.css' );
	wp_enqueue_style( 'swiper', BLOXIC_CSS_PATH . '/swiper.css' );
	wp_enqueue_style( 'preloader', BLOXIC_CSS_PATH . '/preloader.css' );
	wp_enqueue_style( 'magnific-popup', BLOXIC_CSS_PATH . '/magnific-popup.css' );
	wp_enqueue_style( 'custom-animate', BLOXIC_CSS_PATH . '/custom-animate.css' );
	wp_enqueue_style( 'icofont', BLOXIC_CSS_PATH . '/icofont.css' );
	wp_enqueue_style( 'select-style', BLOXIC_CSS_PATH . '/select-style.css' );
	wp_enqueue_style( 'bloxic-global', BLOXIC_CSS_PATH . '/global.css' );
	wp_enqueue_style( 'bloxic-header', BLOXIC_CSS_PATH . '/header.css' );
	wp_enqueue_style( 'bloxic-footer', BLOXIC_CSS_PATH . '/footer.css' );
	wp_enqueue_style( 'bloxic-post-style', BLOXIC_CSS_PATH . '/post-style.css' );
	wp_enqueue_style( 'bloxic-main', BLOXIC_CSS_PATH . '/style.css' );
	wp_enqueue_style( 'bloxic-woocommerce', BLOXIC_CSS_PATH . '/woocommerce.css' );
	wp_enqueue_style( 'bloxic-responsive', BLOXIC_CSS_PATH . '/responsive.css' );
	wp_enqueue_style( 'bloxic-style', get_stylesheet_uri(), array(), '1.0' );
	
	
	wp_enqueue_script('jquery-ui-selectmenu');
	wp_enqueue_script( 'popper', BLOXIC_JS_PATH . '/popper.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'bootstrap', BLOXIC_JS_PATH . '/bootstrap.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'magnific-popup', BLOXIC_JS_PATH . '/magnific-popup.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'appear', BLOXIC_JS_PATH . '/appear.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'parallax', BLOXIC_JS_PATH . '/parallax.min.js', array('jquery'), '1.0', true );
	//wp_enqueue_script( 'tilt-jquery', BLOXIC_JS_PATH . '/tilt.jquery.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'jquery-paroller', BLOXIC_JS_PATH . '/jquery.paroller.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'owl', BLOXIC_JS_PATH . '/owl.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'wow', BLOXIC_JS_PATH . '/wow.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'jquery-countdown', BLOXIC_JS_PATH . '/jquery.countdown.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'swiper', BLOXIC_JS_PATH . '/swiper.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'touchspin', BLOXIC_JS_PATH . '/touchspin.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'odometer', BLOXIC_JS_PATH . '/odometer.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'mixitup', BLOXIC_JS_PATH . '/mixitup.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'jquery-marquee', BLOXIC_JS_PATH . '/jquery.marquee.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'nav-tool', BLOXIC_JS_PATH . '/nav-tool.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'bloxic-script', BLOXIC_JS_PATH . '/script.js', array('jquery'), '1.0', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'bloxic_scripts' );

/**
 * Implement the Custom Header feature.
 */
require BLOXIC_THEME_DRI . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require BLOXIC_THEME_DRI . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require BLOXIC_THEME_DRI . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require BLOXIC_THEME_DRI . '/inc/customizer.php';

/**
 * Theme Optionpanel & Metabox Settings
 */
require BLOXIC_THEME_DRI . '/inc/cs-framework-functions.php';

/**
 * Nav Walker
 */
require BLOXIC_THEME_DRI . '/inc/class-wp-bloxic-navwalker.php';

/**
 * Recommendation Plugin Activation
 */
require BLOXIC_THEME_DRI . '/lib/plugin-activation.php';

/**
 * Theme Core Function
 */
require BLOXIC_THEME_DRI . '/inc/bloxic-functions.php';

/**
 * Demo Import
 */
require BLOXIC_THEME_DRI . '/lib/ocdi/functions.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require BLOXIC_THEME_DRI . '/inc/jetpack.php';
}

/**
 * Woocommerce Hook Control
 *
 * @return void
 */
if(class_exists('Woocommerce')){
	function bloxic_woo_theme_init(){
		$bloxic_exlude_hooks = require BLOXIC_THEME_DRI . '/inc/remove_actions.php';
		foreach( $bloxic_exlude_hooks as $k => $v )
		{
			foreach( $v as $value )
			remove_action( $k, $value[0], $value[1] );
		}

	}
	add_action( 'init', 'bloxic_woo_theme_init');
}

function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1717520845747';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        